#
# src/kernel/Makefile
#

include /crux-arm/ct-ng/vars.mk

#TARGET = arm-crux-linux-gnueabi
#WORK = $(PWD)/work
#CLFS = /crux-arm/clfs
#CROSSTOOLS = /opt/crosstools

KERNEL_VERSION = 2.6.21

.PHONY: all clean image modules map config

all: image modules map

clean: image-clean modules-clean map-clean

distclean: clean image-distclean modules-distclean map-distclean

$(WORK)/linux-$(KERNEL_VERSION).tar.bz2:
	wget -P $(WORK) ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-$(KERNEL_VERSION).tar.bz2
	wget -P $(WORK) ftp://ftp.embeddedarm.com/ts-arm-sbc/ts-7350-linux/sources/linux-2.6.21-ts-src-feb022010.tar.gz
	cp linux-2.6.21-ts.patch $(WORK)
	cp max_path.patch $(WORK)

$(WORK)/linux-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION).tar.bz2
	tar -C $(WORK) -xjf $(WORK)/linux-$(KERNEL_VERSION).tar.bz2
	tar -C $(WORK) -xzf $(WORK)/linux-$(KERNEL_VERSION)-ts-src-feb022010.tar.gz
	find $(WORK)/linux-2.6.21-ts -type d -name CVS | xargs rm -rf
	#cd $(WORK) && \
	#	diff -Nuar linux-$(KERNEL_VERSION) linux-$(KERNEL_VERSION)-ts > linux-$(KERNEL_VERSION)-ts.patch
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		patch -p1 < $(WORK)/linux-2.6.21-ts.patch && \
		patch -p1 < $(WORK)/max_path.patch
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		make mrproper && \
		make ARCH=arm ts7350_defconfig && \
		make ARCH=arm oldconfig
	touch $(WORK)/linux-$(KERNEL_VERSION)

$(WORK)/zImage-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION)
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		export PATH=$(CROSSTOOLS)/bin:$$PATH && \
		export LD_LIBRARY_PATH=$(CROSSTOOLS)/lib:$$LD_LIBRARY_PATH && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- zImage V=1
	cp -v $(WORK)/linux-$(KERNEL_VERSION)/arch/arm/boot/zImage $(WORK)/zImage-$(KERNEL_VERSION)
	cp -v $(WORK)/zImage-$(KERNEL_VERSION) $(CLFS)/boot/
	touch $(WORK)/zImage-$(KERNEL_VERSION)

image: $(WORK)/zImage-$(KERNEL_VERSION)

image-clean:
	rm -vrf $(WORK)/linux-$(KERNEL_VERSION) $(WORK)/zImage-$(KERNEL_VERSION)

image-distclean: image-clean

$(WORK)/modules-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION)
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		export PATH=$(CROSSTOOLS)/bin:$$PATH && \
		export LD_LIBRARY_PATH=$(LD_LIBRARY_PATH)/lib:$$LD_LIBRARY_PATH && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- modules && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- INSTALL_MOD_PATH=$(WORK)/modules-$(KERNEL_VERSION) modules_install
	rm -f $(WORK)/modules-$(KERNEL_VERSION)/lib/modules/$(KERNEL_VERSION)/{source,build}
	touch $(WORK)/modules-$(KERNEL_VERSION)

modules: $(WORK)/modules-$(KERNEL_VERSION)

modules-clean:
	rm -vrf $(WORK)/modules-$(KERNEL_VERSION)

modules-distclean: modules-clean

$(WORK)/System.map-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION)
	cp $(WORK)/linux-$(KERNEL_VERSION)/System.map $(WORK)/System.map-$(KERNEL_VERSION)
	cp $(WORK)/System.map-$(KERNEL_VERSION) $(CLFS)/boot/
	touch $(WORK)/System.map-$(KERNEL_VERSION)

map: $(WORK)/System.map-$(KERNEL_VERSION)

map-clean:
	rm -vrf $(WORK)/System.map-$(KERNEL_VERSION)

map-distclean: map-clean

config: $(WORK)/linux-$(KERNEL_VERSION)
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		export PATH=$(CROSSTOOLS)/bin:$$PATH && \
		export LD_LIBRARY_PATH=$(CROSSTOOLS)/lib:$$LD_LIBRARY_PATH && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- menuconfig
	touch $(WORK)/linux-$(KERNEL_VERSION)

# End of file
